@@ -2,22 +2,22 @@ drake_context("map reduce")
 
 test_with_dir("map_plan()", {
   skip_on_cran()
-  f <- function(a, b) {
+  fn <- function(a, b) {
     a + b
   }
   args <- expand.grid(a = 1:2, b = 3:5)
-  plan1 <- map_plan(args = args, fun = f)
+  plan1 <- map_plan(args = args, fun = fn)
   args$id <- LETTERS[seq_len(nrow(args))]
-  plan2 <- map_plan(args = args, fun = f)
+  plan2 <- map_plan(args = args, fun = fn)
   args$x <- args$id
   args$id <- NULL
-  plan3 <- map_plan(args = args, fun = f, id = x)
-  plan4 <- map_plan(args = args, fun = "f", id = "x", character_only = TRUE)
-  plan5 <- map_plan(args = args, fun = f, id = x, trace = TRUE)
-  expect_equal(plan1$command, plan2$command)
-  expect_equal(plan2, plan3)
-  expect_equal(plan3, plan4)
-  expect_equal(tibble::as_tibble(cbind(plan3, args)), plan5)
+  plan3 <- map_plan(args = args, fun = fn, id = x)
+  plan4 <- map_plan(args = args, fun = "fn", id = "x", character_only = TRUE)
+  plan5 <- map_plan(args = args, fun = fn, id = x, trace = TRUE)
+  expect_equal(deparse_lang_col(plan1$command), deparse_lang_col(plan2$command))
+  equivalent_plans(plan2, plan3)
+  equivalent_plans(plan3, plan4)
+  equivalent_plans(weak_as_tibble(cbind(plan3, args)), plan5)
   cache <- storr::storr_environment()
   make(plan2, session_info = FALSE, cache = cache)
   expect_equal(
@@ -31,10 +31,11 @@ test_with_dir("map_plan()", {
 
 test_with_dir("map_plan() onto a matrix", {
   skip_on_cran()
+  skip_if_not_installed("datasets")
   my_model_fit <- function(x1, x2) {
-    lm(as.formula(paste("mpg ~", x1, "+", x2)), data = mtcars)
+    lm(as.formula(paste("mpg ~", x1, "+", x2)), data = datasets::mtcars)
   }
-  covariates <- setdiff(colnames(mtcars), "mpg")
+  covariates <- setdiff(colnames(datasets::mtcars), "mpg")
   args <- t(combn(covariates, 2))
   colnames(args) <- c("x1", "x2")
   plan <- map_plan(args, "my_model_fit")
@@ -46,14 +47,15 @@ test_with_dir("map_plan() onto a matrix", {
 
 test_with_dir("map_plan() with symbols", {
   skip_on_cran()
+  skip_if_not_installed("datasets")
   my_model_fit <- function(x1, x2, data) {
     formula <- as.formula(paste("mpg ~", x1, "+", x1))
     lm(formula, data = data)
   }
-  covariates <- setdiff(colnames(mtcars), "mpg")
+  covariates <- setdiff(colnames(datasets::mtcars), "mpg")
   args <- t(combn(covariates, 2))
   colnames(args) <- c("x1", "x2")
-  args <- tibble::as_tibble(args)
+  args <- weak_as_tibble(args)
   args$data <- rlang::syms(rep("mtcars", nrow(args)))
   plan <- map_plan(args, my_model_fit)
   cache <- storr::storr_environment()
@@ -65,26 +67,28 @@ test_with_dir("map_plan() with symbols", {
 test_with_dir("gather_plan()", {
   df <- drake_plan(data = simulate(center = MU, scale = SIGMA))
   m0 <- evaluate_plan(df, wildcard = "NULL", values = 1:2)
-  expect_equal(m0, df)
+  equivalent_plans(m0, df)
   m1 <- evaluate_plan(df, rules = list(nothing = 1:2), expand = FALSE)
-  expect_equal(m1, df)
+  equivalent_plans(m1, df)
   x <- expand_plan(df, values = c("rep1", "rep2"))
   x6 <- gather_plan(x, append = FALSE)
-  y <- tibble::tibble(
-    target = "target",
-    command = "list(data_rep1 = data_rep1, data_rep2 = data_rep2)"
+  y <- sanitize_plan(
+    weak_tibble(
+      target = "target",
+      command = "list(data_rep1 = data_rep1, data_rep2 = data_rep2)"
+    )
   )
-  expect_equal(x6, y)
+  equivalent_plans(x6, y)
   z <- gather_plan(x, append = TRUE)
-  expect_equal(z, bind_plans(x, y))
+  equivalent_plans(z, bind_plans(x, y))
   x7 <- gather_plan(
     x, target = "my_summaries", gather = "rbind", append = FALSE
   )
-  y <- tibble::tibble(
+  y <- weak_tibble(
     target = "my_summaries",
     command = "rbind(data_rep1 = data_rep1, data_rep2 = data_rep2)"
   )
-  expect_equal(x7, y)
+  equivalent_plans(x7, y)
 })
 
 test_with_dir("reduce_plan()", {
@@ -99,24 +103,24 @@ test_with_dir("reduce_plan()", {
     x_plan, target = "x_sum", pairwise = FALSE,
     begin = "", end = "", append = FALSE
   )
-  x0 <- tibble::tibble(
+  x0 <- weak_tibble(
     target = "x_sum",
     command = paste0(x_plan$target, collapse = " + ")
   )
-  expect_equal(x, x0)
+  equivalent_plans(x, x0)
   z <- reduce_plan(
     x_plan, target = "x_sum", pairwise = FALSE,
     begin = "", end = "", append = TRUE
   )
   z0 <- bind_plans(x_plan, x)
-  expect_equal(z, z0)
+  equivalent_plans(z, z0)
   make(rbind(x_plan, x), session_info = FALSE)
   expect_equal(readd(x_sum), sum(1:8))
   clean(destroy = TRUE)
 
   # Pairwise reduce even number of targets
   x <- reduce_plan(x_plan, target = "x_sum", pairwise = TRUE)
-  x0 <- tibble(
+  x0 <- weak_tibble(
     target = c(paste0("x_sum_", 1:6), "x_sum"),
     command = c(
       "x_1 + x_2", "x_3 + x_4", "x_5 + x_6", "x_7 + x_8",
@@ -124,18 +128,18 @@ test_with_dir("reduce_plan()", {
       "x_sum_5 + x_sum_6"
     )
   )
-  expect_equal(x, x0)
+  equivalent_plans(x, x0)
   x <- reduce_plan(
     x_plan, target = "x_sum", pairwise = FALSE,
     begin = "", end = ""
   )
-  x0 <- tibble::tibble(
+  x0 <- weak_tibble(
     target = "x_sum",
     command = paste0(x_plan$target, collapse = " + ")
   )
-  expect_equal(x, x0)
+  equivalent_plans(x, x0)
   x <- reduce_plan(x_plan, target = "x_sum", pairwise = TRUE)
-  x0 <- tibble(
+  x0 <- weak_tibble(
     target = c(paste0("x_sum_", 1:6), "x_sum"),
     command = c(
       "x_1 + x_2", "x_3 + x_4", "x_5 + x_6", "x_7 + x_8",
@@ -143,7 +147,7 @@ test_with_dir("reduce_plan()", {
       "x_sum_5 + x_sum_6"
     )
   )
-  expect_equal(x, x0)
+  equivalent_plans(x, x0)
   make(rbind(x_plan, x), session_info = FALSE)
   expect_equal(readd(x_sum), sum(1:8))
   clean(destroy = TRUE)
@@ -155,7 +159,7 @@ test_with_dir("reduce_plan()", {
     values = 1:9
   )
   x <- reduce_plan(x_plan, target = "x_sum", pairwise = TRUE)
-  x0 <- tibble(
+  x0 <- weak_tibble(
     target = c(paste0("x_sum_", 1:7), "x_sum"),
     command = c(
       "x_1 + x_2", "x_3 + x_4", "x_5 + x_6", "x_7 + x_8",
@@ -164,7 +168,7 @@ test_with_dir("reduce_plan()", {
       "x_sum_6 + x_sum_7"
     )
   )
-  expect_equal(x, x0)
+  equivalent_plans(x, x0)
   make(rbind(x_plan, x), session_info = FALSE)
   expect_equal(readd(x_sum), sum(1:9))
   clean(destroy = TRUE)
@@ -180,7 +184,7 @@ test_with_dir("reduce_plan()", {
   }
   x <- reduce_plan(x_plan, target = "x_sum", pairwise = TRUE,
                    begin = "fun(", op = ", ", end = ")")
-  x0 <- tibble(
+  x0 <- weak_tibble(
     target = c(paste0("x_sum_", 1:6), "x_sum"),
     command = c(
       "fun(x_1, x_2)", "fun(x_3, x_4)", "fun(x_5, x_6)", "fun(x_7, x_8)",
@@ -188,7 +192,7 @@ test_with_dir("reduce_plan()", {
       "fun(x_sum_5, x_sum_6)"
     )
   )
-  expect_equal(x, x0)
+  equivalent_plans(x, x0)
   make(rbind(x_plan, x))
   out <- fun(
     fun(
@@ -214,18 +218,15 @@ test_with_dir("gather_by()", {
     trace = TRUE
   )
   x <- gather_by(plan, append = TRUE)
-  y <- tibble::tibble(
-    target = c(plan$target, "target"),
-    command = c(
-      plan$command,
-      "list(x_1 = x_1, x_2 = x_2, y_a = y_a, y_b = y_b, z = z)"
-    )
+  new_row <- drake_plan(
+    target = list(x_1 = x_1, x_2 = x_2, y_a = y_a, y_b = y_b, z = z)
   )
-  expect_equal(x[, c("target", "command")], y)
+  y <- bind_plans(plan, new_row)
+  equivalent_plans(x[, c("target", "command")], y)
   x <- gather_by(plan, append = TRUE, sep = ".")
-  expect_equal(x[, c("target", "command")], y)
+  equivalent_plans(x[, c("target", "command")], y)
   z <- gather_by(plan, append = FALSE)
-  expect_equal(z[, c("target", "command")], y[nrow(y), ])
+  equivalent_plans(z[, c("target", "command")], y[nrow(y), ])
   x <- gather_by(
     plan,
     n___from,
@@ -234,7 +235,7 @@ test_with_dir("gather_by()", {
     append = TRUE,
     sep = "."
   )
-  y <- tibble::tibble(
+  y <- weak_tibble(
     target = c("xyz.y", "xyz.NA"),
     command = c("c(y_a = y_a, y_b = y_b)", "c(x_1 = x_1, x_2 = x_2, z = z)"),
     m__ = as.character(NA),
@@ -242,9 +243,10 @@ test_with_dir("gather_by()", {
     n__ = NA,
     n___from = c("y", NA)
   )
-  expect_equal(x, bind_plans(plan, y))
+  y <- sanitize_plan(y)
+  equivalent_plans(x, bind_plans(plan, y))
   x <- gather_by(plan, n___from, prefix = "xyz", gather = "c", append = TRUE)
-  y <- tibble::tibble(
+  y <- weak_tibble(
     target = c("xyz_y", "xyz_NA"),
     command = c("c(y_a = y_a, y_b = y_b)", "c(x_1 = x_1, x_2 = x_2, z = z)"),
     m__ = as.character(NA),
@@ -252,10 +254,11 @@ test_with_dir("gather_by()", {
     n__ = NA,
     n___from = c("y", NA)
   )
+  y <- sanitize_plan(y)
   expected <- bind_plans(plan, y)
-  expect_equal(x[order(x$target), ], expected[order(expected$target), ])
+  equivalent_plans(x[order(x$target), ], expected[order(expected$target), ])
   x <- gather_by(plan, m__, n__, prefix = "xyz", gather = "c", append = TRUE)
-  y <- tibble::tibble(
+  y <- weak_tibble(
     target = c("xyz_1_NA", "xyz_2_NA", "xyz_NA_a", "xyz_NA_b", "xyz_NA_NA"),
     command = c(
       "c(x_1 = x_1)",
@@ -269,8 +272,9 @@ test_with_dir("gather_by()", {
     n__ = c(NA, NA, "a", "b", NA),
     n___from = as.character(NA)
   )
+  y <- sanitize_plan(y)
   expected <- bind_plans(plan, y)
-  expect_equal(x[order(x$target), ], expected[order(expected$target), ])
+  equivalent_plans(x[order(x$target), ], expected[order(expected$target), ])
   plan$n___from <- c("x", "x", "y", "y", NA)
   x <- gather_by(
     plan,
@@ -280,11 +284,9 @@ test_with_dir("gather_by()", {
     append = TRUE,
     filter = n___from == "x"
   )
-  y <- tibble::tibble(
-    target = c(plan$target, "xyz_x"),
-    command = c(plan$command, "c(x_1 = x_1, x_2 = x_2)")
-  )
-  expect_equal(x[, c("target", "command")], y)
+  new_row <- drake_plan(xyz_x = c(x_1 = x_1, x_2 = x_2))
+  y <- bind_plans(plan, new_row)
+  equivalent_plans(x[, c("target", "command")], y)
 })
 
 test_with_dir("reduce_by()", {
@@ -298,13 +300,11 @@ test_with_dir("reduce_by()", {
     trace = TRUE
   )
   x <- reduce_by(plan, pairwise = FALSE, append = TRUE)
-  y <- tibble::tibble(
-    target = c(plan$target, "target"),
-    command = c(plan$command, "x_1 + x_2 + x_3 + x_4 + y_a + y_b + z")
-  )
-  expect_equal(x[, c("target", "command")], y)
+  new_row <- drake_plan(target = x_1 + x_2 + x_3 + x_4 + y_a + y_b + z)
+  y <- bind_plans(plan, new_row)
+  equivalent_plans(x[, c("target", "command")], y)
   z <- reduce_by(plan, pairwise = FALSE, append = FALSE)
-  expect_equal(z[, c("target", "command")], y[nrow(y), ])
+  equivalent_plans(z[, c("target", "command")], y[nrow(y), ])
   x <- reduce_by(
     plan, m___from,
     prefix = "xyz",
@@ -314,7 +314,7 @@ test_with_dir("reduce_by()", {
     append = TRUE,
     sep = "."
   )
-  y <- tibble::tibble(
+  y <- weak_tibble(
     target = c("xyz.1.x", "xyz.2.x", "xyz.x", "xyz.1.NA", "xyz.NA"),
     command = c(
       "c(x_1, x_2)",
@@ -328,8 +328,9 @@ test_with_dir("reduce_by()", {
     n__ = as.character(NA),
     n___from = as.character(NA)
   )
+  y <- sanitize_plan(y)
   expected <- bind_plans(plan, y)
-  expect_equal(x[order(x$target), ], expected[order(expected$target), ])
+  equivalent_plans(x[order(x$target), ], expected[order(expected$target), ])
   x <- reduce_by(
     plan, m___from,
     prefix = "xyz",
@@ -338,7 +339,7 @@ test_with_dir("reduce_by()", {
     end = ")",
     append = TRUE
   )
-  y <- tibble::tibble(
+  y <- weak_tibble(
     target = c("xyz_1_x", "xyz_2_x", "xyz_x", "xyz_1_NA", "xyz_NA"),
     command = c(
       "c(x_1, x_2)", "c(x_3, x_4)", "c(xyz_1, xyz_2)",
@@ -349,13 +350,14 @@ test_with_dir("reduce_by()", {
     n__ = as.character(NA),
     n___from = as.character(NA)
   )
+  y <- sanitize_plan(y)
   expected <- bind_plans(plan, y)
-  expect_equal(x[order(x$target), ], expected[order(expected$target), ])
+  equivalent_plans(x[order(x$target), ], expected[order(expected$target), ])
   x <- reduce_by(
     plan, m___from, prefix = "xyz", op = ", ", begin = "c(", end = ")",
     pairwise = FALSE, append = TRUE
   )
-  y <- tibble::tibble(
+  y <- weak_tibble(
     target = c("xyz_x", "xyz_NA"),
     command = c("c(c(c(x_1, x_2), x_3), x_4)", "c(c(y_a, y_b), z)"),
     m__ = as.character(NA),
@@ -363,10 +365,11 @@ test_with_dir("reduce_by()", {
     n__ = as.character(NA),
     n___from = as.character(NA)
   )
+  y <- sanitize_plan(y)
   expected <- bind_plans(plan, y)
-  expect_equal(x[order(x$target), ], expected[order(expected$target), ])
+  equivalent_plans(x[order(x$target), ], expected[order(expected$target), ])
   x <- reduce_by(plan, m___from, n___from, append = TRUE)
-  y <- tibble::tibble(
+  y <- weak_tibble(
     target = c(
       "target_1_x_NA",
       "target_2_x_NA",
@@ -384,10 +387,11 @@ test_with_dir("reduce_by()", {
     n__ = as.character(NA),
     n___from = c(rep(NA, 3), "y")
   )
+  y <- sanitize_plan(y)
   expected <- bind_plans(plan, y)
-  expect_equal(x[order(x$target), ], expected[order(expected$target), ])
+  equivalent_plans(x[order(x$target), ], expected[order(expected$target), ])
   x <- reduce_by(plan, m___from, n___from, pairwise = FALSE, append = TRUE)
-  y <- tibble::tibble(
+  y <- weak_tibble(
     target = c(
       "target_x_NA",
       "target_NA_y",
@@ -403,8 +407,9 @@ test_with_dir("reduce_by()", {
     n__ = as.character(NA),
     n___from = c(NA, "y", NA)
   )
+  y <- sanitize_plan(y)
   expected <- bind_plans(plan, y)
-  expect_equal(x[order(x$target), ], expected[order(expected$target), ])
+  equivalent_plans(x[order(x$target), ], expected[order(expected$target), ])
   plan$from <- c(rep("x", 4), rep("y", 2), NA)
   x <- reduce_by(
     plan,
@@ -414,9 +419,7 @@ test_with_dir("reduce_by()", {
     pairwise = FALSE,
     filter = from == "y"
   )
-  y <- tibble::tibble(
-    target = c(plan$target, "xyz_y"),
-    command = c(plan$command, "y_a + y_b")
-  )
-  expect_equal(x[, c("target", "command")], y)
+  new_row <- drake_plan(xyz_y = y_a + y_b)
+  y <- bind_plans(plan, new_row)
+  equivalent_plans(x[, c("target", "command")], y)
 })
