@@ -1,19 +1,5 @@
 drake_context("other features")
 
-test_with_dir("Can standardize commands from expr or lang", {
-  skip_on_cran() # CRAN gets whitelist tests only (check time limits).
-  x <- parse(text = c("f(x +2) + 2", "!!y"))
-  y <- standardize_command(x[[1]])
-  x <- parse(text = "f(x +2) + 2")
-  z <- standardize_command(x)
-  w <- standardize_command(x[[1]])
-  s <- "{\n f(x + 2) + 2 \n}"
-  debug_char0 <-
-  expect_equal(y, s)
-  expect_equal(z, s)
-  expect_equal(w, s)
-})
-
 test_with_dir("debug_command()", {
   skip_on_cran()
   txt <- "    f(x + 2) + 2"
@@ -21,15 +7,15 @@ test_with_dir("debug_command()", {
   x <- parse(text = txt)[[1]]
   out1 <- debug_command(x)
   out2 <- debug_command(txt)
-  txt3 <- rlang::expr_text(out1)
+  txt3 <- safe_deparse(out1)
   expect_equal(out2, txt2)
   expect_equal(out2, txt3)
 })
 
 test_with_dir("build_target() does not need to access cache", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
-  config <- drake_config(drake_plan(x = 1))
-  meta <- drake_meta(target = "x", config = config)
+  config <- drake_config(drake_plan(x = 1), lock_envir = FALSE)
+  meta <- drake_meta_(target = "x", config = config)
   config$cache <- NULL
   build <- build_target(target = "x", meta = meta, config = config)
   expect_equal(1, build$value)
@@ -57,32 +43,35 @@ test_with_dir("drake_build works as expected", {
   scenario <- get_testing_scenario()
   e <- eval(parse(text = scenario$envir))
   pl <- drake_plan(a = 1, b = a)
-  con <- drake_config(plan = pl, session_info = FALSE, envir = e)
+  con <- drake_config(
+    plan = pl,
+    session_info = FALSE,
+    envir = e,
+    lock_envir = TRUE
+  )
 
   # can run before any make()
   o <- drake_build(
-    target = "a", character_only = TRUE, config = con, envir = e)
+    target = "a", character_only = TRUE, config = con)
   x <- cached()
   expect_equal(x, "a")
-  o <- make(pl, envir = e)
+  make(pl, envir = e)
+  o <- drake_config(pl, envir = e)
   expect_equal(justbuilt(o), "b")
 
-  # Can run without config
-  o <- drake_build(b, envir = e)
-  expect_equal(o, readd(b))
-
   # Replacing deps in environment
-  expect_equal(e$a, 1)
-  e$a <- 2
-  o <- drake_build(b, envir = e)
-  expect_equal(e$a, 2)
+  con$eval$a <- 2
+  o <- drake_build(b, config = con)
+  expect_equal(o, 2)
+  expect_equal(con$eval$a, 2)
   expect_equal(readd(a), 1)
-  o <- drake_build(b, envir = e, replace = FALSE)
-  expect_equal(e$a, 2)
+  o <- drake_build(b, config = con, replace = FALSE)
+  expect_equal(con$eval$a, 2)
   expect_equal(readd(a), 1)
-  e$a <- 3
-  o <- drake_build(b, envir = e, replace = TRUE)
-  expect_equal(e$a, 1)
+  con$eval$a <- 3
+  o <- drake_build(b, config = con, replace = TRUE)
+  expect_equal(con$eval$a, 1)
+  expect_equal(o, 1)
 
   # `replace` in loadd()
   e$b <- 1
@@ -99,7 +88,6 @@ test_with_dir("drake_build works as expected", {
 
 test_with_dir("colors and shapes", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
-  expect_message(drake_palette())
   expect_is(color_of("target"), "character")
   expect_is(color_of("import"), "character")
   expect_is(color_of("not found"), "character")
@@ -126,34 +114,12 @@ test_with_dir("make() with skip_targets", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   expect_silent(make(drake_plan(x = 1), skip_targets = TRUE,
     verbose = FALSE, session_info = FALSE))
-  expect_false(cached(x))
-})
-
-test_with_dir("in_progress() works and errors are handled correctly", {
-  skip_on_cran() # CRAN gets whitelist tests only (check time limits).
-  expect_equal(in_progress(), character(0))
-  bad_plan <- drake_plan(x = function_doesnt_exist())
-  expect_error(
-    make(bad_plan, verbose = TRUE, session_info = FALSE))
-  expect_equal(failed(), "x")
-  expect_equal(in_progress(), character(0))
-  expect_is(e <- diagnose(x)$error, "error")
-  expect_true(
-    grepl(
-      pattern = "function_doesnt_exist",
-      x = e$message,
-      fixed = TRUE
-    )
-  )
-  expect_error(diagnose("notfound"))
-  expect_true(inherits(diagnose(x)$error, "error"))
-  y <- "x"
-  expect_true(inherits(diagnose(y, character_only = TRUE)$error, "error"))
+  expect_false("x" %in% cached())
 })
 
 test_with_dir("warnings and messages are caught", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
-  expect_equal(in_progress(), character(0))
+  expect_equal(nrow(progress()), 0)
   f <- function(x) {
     warning("my first warn")
     message("my first mess")
@@ -170,7 +136,7 @@ test_with_dir("warnings and messages are caught", {
   expect_true(grepl("my second mess", x$messages[2], fixed = TRUE))
 })
 
-test_with_dir("missed() works", {
+test_with_dir("missed() works with in-memory deps", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   # May have been loaded in a globalenv() testing scenario
   remove_these <- intersect(ls(envir = globalenv()), c("f", "g"))
@@ -181,6 +147,14 @@ test_with_dir("missed() works", {
   expect_equal(sort(c("f", "g")), sort(missed(o)))
 })
 
+test_with_dir("missed() works with files", {
+  skip_on_cran() # CRAN gets whitelist tests only (check time limits).
+  o <- dbug()
+  expect_equal(character(0), missed(o))
+  unlink("input.rds")
+  expect_equal(display_keys(encode_path("input.rds")), missed(o))
+})
+
 test_with_dir(".onLoad() warns correctly and .onAttach() works", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   f <- ".RData"
@@ -191,26 +165,21 @@ test_with_dir(".onLoad() warns correctly and .onAttach() works", {
   expect_warning(drake:::.onLoad())
   unlink(f, force = TRUE)
   set.seed(0)
-  expect_true(is.character(drake_tip()))
   expect_silent(suppressPackageStartupMessages(drake:::.onAttach()))
 })
 
-test_with_dir("check_drake_config() via check_plan() and make()", {
+test_with_dir("config_checks() via make()", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   config <- dbug()
   y <- data.frame(x = 1, y = 2)
-  suppressWarnings(expect_error(check_plan(y, envir = config$envir)))
   suppressWarnings(
     expect_error(
       make(y, envir = config$envir, session_info = FALSE, verbose = FALSE)))
   y <- data.frame(target = character(0), command = character(0))
-  expect_error(suppressWarnings(check_plan(y, envir = config$envir)))
   suppressWarnings(
     expect_error(
       make(y, envir = config$envir,
            session_info = FALSE, verbose = FALSE)))
-  suppressWarnings(expect_error(
-    check_plan(config$plan, targets = character(0), envir = config$envir)))
   suppressWarnings(expect_error(
     make(
       config$plan,
@@ -232,54 +201,62 @@ test_with_dir("targets can be partially specified", {
   config$targets <- "final"
   testrun(config)
   expect_true(is.numeric(readd(final, search = FALSE)))
-  pl <- drake_plan(x = 1, y = 2)
-  expect_error(check_plan(pl, "lskjdf", verbose = FALSE))
-  expect_warning(check_plan(pl, c("lskdjf", "x"), verbose = FALSE))
-  expect_silent(check_plan(pl, verbose = FALSE))
 })
 
 test_with_dir("file_store quotes properly", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
-  expect_equal(file_store("x"), "\"x\"")
+  expect_equal(file_store("x"), encode_path("x"))
 })
 
 test_with_dir("misc utils", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   expect_equal(pair_text("x", c("y", "z")), c("xy", "xz"))
   config <- list(plan = data.frame(x = 1, y = 2))
-  expect_error(check_drake_config(config), regexp = "columns")
+  expect_error(config_checks(config), regexp = "columns")
   expect_error(targets_from_dots(123, NULL), regexp = "must contain names")
 })
 
 test_with_dir("make(..., skip_imports = TRUE) works", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   con <- dbug()
-  verbose <- max(con$jobs) < 2 &&
-    targets_setting(con$parallelism) == "parLapply"
-  suppressMessages(
-    con <- make(
+  verbose <- max(con$jobs) < 2
+  suppressMessages({
+    make(
       con$plan, parallelism = con$parallelism,
       envir = con$envir, jobs = con$jobs, verbose = verbose,
       skip_imports = TRUE,
       session_info = FALSE
     )
-  )
+    con <- drake_config(
+      con$plan, parallelism = con$parallelism,
+      envir = con$envir, jobs = con$jobs, verbose = verbose,
+      skip_imports = TRUE,
+      session_info = FALSE
+    )
+  })
   expect_equal(
-    sort(cached()),
-    sort(c("\"intermediatefile.rds\"", con$plan$target))
+    sort(cached(targets_only = FALSE)),
+    sort(display_keys(
+      c(encode_path("intermediatefile.rds"), con$plan$target)
+    ))
   )
 
   # If the imports are already cached, the targets built with
   # skip_imports = TRUE should be up to date.
   make(con$plan, verbose = FALSE, envir = con$envir, session_info = FALSE)
   clean(list = con$plan$target, verbose = FALSE)
-  suppressMessages(
-    con <- make(
+  suppressMessages({
+    make(
       con$plan, parallelism = con$parallelism,
       envir = con$envir, jobs = con$jobs, verbose = verbose,
       skip_imports = TRUE, session_info = FALSE
     )
-  )
+    con <- drake_config(
+      con$plan, parallelism = con$parallelism,
+      envir = con$envir, jobs = con$jobs, verbose = verbose,
+      skip_imports = TRUE, session_info = FALSE
+    )
+  })
   out <- outdated(con)
   expect_equal(out, character(0))
 })
@@ -300,3 +277,132 @@ test_with_dir("assert_pkg", {
     regexp = "with BiocManager::install"
   )
 })
+
+test_with_dir("packages are loaded and prework is run", {
+  skip_on_cran() # CRAN gets whitelist tests only (check time limits).
+  skip_if_not_installed("abind")
+  on.exit(options(test_drake_option_12345 = NULL))
+
+  options(test_drake_option_12345 = "unset")
+  expect_equal(getOption("test_drake_option_12345"), "unset")
+  config <- dbug()
+  try(detach("package:abind", unload = TRUE), silent = TRUE) # nolint
+  expect_error(abind(1))
+
+  # Load packages with the 'packages' argument
+  config$packages <- "abind"
+  config$prework <- "options(test_drake_option_12345 = 'set')"
+  config$plan <- drake_plan(
+    x = getOption("test_drake_option_12345"),
+    y = c(deparse(body(abind)), x)
+  )
+  config$targets <- config$plan$target
+  expect_false(any(c("x", "y") %in% config$cache$list()))
+  testrun(config)
+  expect_true(all(c("x", "y") %in% config$cache$list()))
+  expect_equal(readd(x, search = FALSE), "set")
+  expect_true(length(readd(y, search = FALSE)) > 0)
+  clean(search = FALSE)
+
+  # load packages the usual way
+  options(test_drake_option_12345 = "unset")
+  expect_equal(getOption("test_drake_option_12345"), "unset")
+  try(detach("package:abind", unload = TRUE), silent = TRUE) # nolint
+  expect_error(abind(1))
+  library(abind) # nolint
+  config$packages <- NULL
+  expect_false(any(c("x", "y") %in% config$cache$list()))
+
+  # drake may be loaded with devtools::load_all() but not
+  # installed.
+  scenario <- get_testing_scenario()
+  suppressWarnings(
+    make(
+      plan = config$plan,
+      targets = config$targets,
+      envir = config$envir,
+      verbose = FALSE,
+      parallelism = scenario$parallelism,
+      jobs = scenario$jobs,
+      prework = config$prework,
+      command = config$command,
+      session_info = FALSE
+    )
+  )
+  expect_true(all(c("x", "y") %in% config$cache$list()))
+  expect_equal(readd(x, search = FALSE), "set")
+  expect_true(length(readd(y, search = FALSE)) > 0)
+})
+
+test_with_dir("prework can be an expression", {
+  on.exit(options(test_drake_option_12345 = NULL))
+  options(test_drake_option_12345 = "unset")
+  expect_equal(getOption("test_drake_option_12345"), "unset")
+  config <- dbug()
+  config$plan <- drake_plan(x = getOption("test_drake_option_12345"))
+  config$targets <- config$plan$target
+  config$prework <- quote(options(test_drake_option_12345 = "set"))
+  testrun(config)
+  expect_equal(readd(x), "set")
+})
+
+test_with_dir("prework can be an expression", {
+  on.exit(
+    options(test_drake_option_12345 = NULL, test_drake_option_6789 = NULL)
+  )
+  options(test_drake_option_12345 = "unset", test_drake_option_6789 = "unset")
+  expect_equal(getOption("test_drake_option_12345"), "unset")
+  expect_equal(getOption("test_drake_option_6789"), "unset")
+  config <- dbug()
+  config$plan <- drake_plan(
+    x = getOption("test_drake_option_12345"),
+    y = getOption("test_drake_option_6789")
+  )
+  config$targets <- config$plan$target
+  config$prework <- list(
+    quote(options(test_drake_option_12345 = "set")),
+    quote(options(test_drake_option_6789 = "set"))
+  )
+  testrun(config)
+  expect_equal(readd(x), "set")
+  expect_equal(readd(y), "set")
+})
+
+test_with_dir("parallelism can be a scheduler function", {
+  plan <- drake_plan(x = file.create("x"))
+  build_ <- function(target, config){
+    tidy_expr <- eval(
+      expr = config$layout[[target]]$command_build,
+      envir = config$eval
+    )
+    eval(expr = tidy_expr, envir = config$eval)
+  }
+  loop_ <- function(config) {
+    targets <- igraph::topo_sort(config$schedule)$name
+    for (target in targets) {
+      console_target(target = target, config = config)
+      config$eval[[target]] <- build_(
+        target = target,
+        config = config
+      )
+    }
+    invisible()
+  }
+  config <- drake_config(plan, parallelism = loop_)
+  expect_warning(
+    make(config = config),
+    regexp = "Use at your own risk"
+  )
+  expect_true(file.exists("x"))
+  expect_false(config$cache$exists("x"))
+})
+
+test_with_dir("running()", {
+  skip_on_cran()
+  plan <- drake_plan(a = 1)
+  cache <- storr::storr_environment()
+  make(plan, session_info = FALSE, cache = cache)
+  expect_equal(running(cache = cache), character(0))
+  cache$set(key = "a", value = "running", namespace = "progress")
+  expect_equal(running(cache = cache), "a")
+})
