@@ -1,47 +1,48 @@
 drake_context("tidy eval")
 
 # From Kendon Bell: https://github.com/ropensci/drake/issues/200
-test_with_dir("drake_plan does tidy eval in `...` argument", {
+test_with_dir("drake_plan does tidy eval", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   my_variable <- 5
-  plan1 <- drake_plan(
-    a = !!my_variable,
-    list = c(d = "!!my_variable")
-  )
-  plan2 <- tibble(
-    target = c("a", "d"),
-    command = c("5", "!!my_variable")
-  )
-  expect_equal(plan1, plan2)
+  plan1 <- drake_plan(a = !!my_variable)
+  plan2 <- weak_tibble(target = "a", command = "5")
+  equivalent_plans(plan1, plan2)
 })
 
 # From Alex Axthelm: https://github.com/ropensci/drake/issues/200
-test_with_dir("drake_plan tidy eval can be disabled", {
+test_with_dir("drake_plan tidy eval can be customized and disabled", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   my_variable <- 5
   plan1 <- drake_plan(
     a = !!my_variable,
     b = !!my_variable + 1,
-    list = c(d = "!!my_variable"),
+    c = target(1 + 1, custom = !!my_variable),
     tidy_evaluation = FALSE
   )
+  plan1$custom <- unlist(lapply(plan1[["custom"]], rlang::expr_text))
   plan2 <- drake_plan(
     a = !!my_variable,
     b = !!my_variable + 1,
-    list = c(d = "!!my_variable"),
+    c = target(1 + 1, custom = !!my_variable),
     tidy_evaluation = TRUE
   )
+  plan1$command <- unclass(deparse_lang_col(plan1$command))
+  plan2$command <- unclass(deparse_lang_col(plan2$command))
   expect_equal(plan1$target, plan2$target)
-  expect_false(identical(plan1$command, plan2$command))
+  expect_false(any(grepl("5", plan1$command)))
+  expect_equal(plan2$command, c("5", "5 + 1", "1 + 1"))
+  expect_false(any(grepl("5", plan1[["custom"]])))
+  expect_equal(plan2$custom, c(NA, NA, 5))
 })
 
 # From Kendon Bell: https://github.com/ropensci/drake/issues/200
 test_with_dir("make() does tidy eval in commands", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
-  plan <- drake_plan(list = c(
-    little_b = "\"b\"",
-    letter = "!!little_b"
-  ))
+  plan <- drake_plan(
+    little_b = "b",
+    letter = !!little_b,
+    tidy_evaluation = FALSE
+  )
   make(plan)
   expect_equal(readd(letter), "b")
 })
