@@ -11,13 +11,19 @@ test_with_dir("empty triggers return logical", {
 
 test_with_dir("triggers can be expressions", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
-  plan <- drake_plan(x = 1)
-  plan$trigger <- expression(trigger(condition = TRUE))
+  plan <- drake_plan(x = target(1, trigger = 123))
+  plan$trigger[[1]] <- expression(trigger(condition = TRUE))
   for (i in 1:3) {
-    config <- make(
+    cache <- storr::storr_environment()
+    make(
       plan,
       session_info = FALSE,
-      cache = storr::storr_environment()
+      cache = cache
+    )
+    config <- drake_config(
+      plan,
+      session_info = FALSE,
+      cache = cache
     )
     expect_equal(justbuilt(config), "x")
   }
@@ -46,15 +52,17 @@ test_with_dir("triggers in plan override make(trigger = whatever)", {
     x = readRDS(file_in("file.rds")),
     y = target(
       readRDS(file_in("file.rds")),
-      trigger(file = TRUE)
-    ),
-    strings_in_dots = "literals"
+      trigger = trigger(file = TRUE)
+    )
   )
-  config <- make(plan, session_info = FALSE)
+  make(plan, session_info = FALSE)
+  config <- drake_config(plan, session_info = FALSE)
   expect_equal(sort(justbuilt(config)), c("x", "y"))
   saveRDS(2, "file.rds")
   expect_equal(sort(outdated(config)), c("x", "y"))
-  config <- make(plan, trigger = trigger(file = FALSE), session_info = FALSE)
+  make(plan, trigger = trigger(file = FALSE), session_info = FALSE)
+  config <- drake_config(
+    plan, trigger = trigger(file = FALSE), session_info = FALSE)
   expect_equal(justbuilt(config), "y")
 })
 
@@ -62,21 +70,23 @@ test_with_dir("change trigger on a fresh build", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   saveRDS(1, "file.rds")
   plan <- drake_plan(
-    x = target(1 + 1, trigger(
+    x = target(1 + 1, trigger = trigger(
       condition = FALSE,
       command = FALSE,
       depend = FALSE,
       file = FALSE,
       change = readRDS("file.rds"))
-    ),
-    strings_in_dots = "literals"
+    )
   )
-  config <- make(plan, session_info = FALSE)
+  make(plan, session_info = FALSE)
+  config <- drake_config(plan, session_info = FALSE)
   expect_equal(justbuilt(config), "x")
-  config <- make(plan, session_info = FALSE)
+  make(plan, session_info = FALSE)
+  config <- drake_config(plan, session_info = FALSE)
   expect_equal(justbuilt(config), character(0))
   saveRDS(2, "file.rds")
-  config <- make(plan, session_info = FALSE)
+  make(plan, session_info = FALSE)
+  config <- drake_config(plan, session_info = FALSE)
   expect_equal(justbuilt(config), "x")
 })
 
@@ -103,6 +113,7 @@ test_with_dir("trigger() function works", {
 
 test_with_dir("can detect trigger deps without reacting to them", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
+  skip_if_not_installed("knitr")
   writeLines("123", "knitr.Rmd")
   saveRDS(0, "file.rds")
   f <- function(x) {
@@ -121,15 +132,14 @@ test_with_dir("can detect trigger deps without reacting to them", {
         depend = TRUE,
         change = NULL
       )
-    ),
-    strings_in_dots = "literals"
+    )
   )
   config <- drake_config(
     plan, session_info = FALSE, cache = storr::storr_environment(),
     log_progress = TRUE)
-  deps <- c(file_store("file.rds"), file_store("knitr.Rmd"), "f")
+  deps <- c(encode_path(c("file.rds", "knitr.Rmd")), "f")
   expect_true(all(deps %in% igraph::V(config$graph)$name))
-  expect_equal(sort(dependencies("x", config)), sort(deps))
+  expect_equal(sort(deps_graph("x", config$graph)), sort(deps))
   expect_equal(outdated(config), "x")
   make(config = config)
   expect_equal(justbuilt(config), "x")
@@ -146,6 +156,7 @@ test_with_dir("can detect trigger deps without reacting to them", {
 
 test_with_dir("same, but with global trigger", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
+  skip_if_not_installed("knitr")
   writeLines("123", "knitr.Rmd")
   saveRDS(0, "file.rds")
   f <- function(x) {
@@ -165,9 +176,9 @@ test_with_dir("same, but with global trigger", {
       change = NULL
     )
   )
-  deps <- c(file_store("file.rds"), file_store("knitr.Rmd"), "f")
+  deps <- c(encode_path(c("file.rds", "knitr.Rmd")), "f")
   expect_true(all(deps %in% igraph::V(config$graph)$name))
-  expect_equal(sort(dependencies("x", config)), sort(deps))
+  expect_equal(sort(deps_graph("x", config$graph)), sort(deps))
   expect_equal(outdated(config), "x")
   make(config = config)
   expect_equal(justbuilt(config), "x")
@@ -184,6 +195,7 @@ test_with_dir("same, but with global trigger", {
 
 test_with_dir("trigger does not block out command deps", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
+  skip_if_not_installed("knitr")
   writeLines("123", "knitr.Rmd")
   saveRDS(0, "file.rds")
   f <- function(x) {
@@ -205,20 +217,19 @@ test_with_dir("trigger does not block out command deps", {
         depend = TRUE,
         change = NULL
       )
-    ),
-    strings_in_dots = "literals"
+    )
   )
   config <- drake_config(
     plan, session_info = FALSE, cache = storr::storr_environment(),
     log_progress = TRUE)
-  deps <- c(file_store("file.rds"), file_store("knitr.Rmd"), "f")
+  deps <- c(encode_path("file.rds"), encode_path("knitr.Rmd"), "f")
   expect_true(all(deps %in% igraph::V(config$graph)$name))
-  expect_equal(sort(dependencies("x", config)), sort(deps))
+  expect_equal(sort(deps_graph("x", config$graph)), sort(deps))
   expect_equal(outdated(config), "x")
-  make(config = config)
+  make(config = config, memory_strategy = "memory")
   expect_equal(justbuilt(config), "x")
   expect_equal(outdated(config), character(0))
-  make(config = config)
+  make(config = config, memory_strategy = "memory")
   nobuild(config)
   f <- function(x) {
     identity(x) || FALSE
@@ -236,8 +247,9 @@ test_with_dir("trigger does not block out command deps", {
   expect_equal(justbuilt(config), "x")
 })
 
-test_with_dir("same, but with global trigger", {
+test_with_dir("same, but with global change trigger", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
+  skip_if_not_installed("knitr")
   writeLines("123", "knitr.Rmd")
   saveRDS(0, "file.rds")
   f <- function(x) {
@@ -247,30 +259,29 @@ test_with_dir("same, but with global trigger", {
     x = {
       knitr_in("knitr.Rmd")
       f(0) + readRDS(file_in("file.rds"))
-    },
-    strings_in_dots = "literals"
+    }
   )
   config <- drake_config(
     plan, session_info = FALSE, cache = storr::storr_environment(),
     log_progress = TRUE, trigger = trigger(
-      condition = {
+      change = {
         knitr_in("knitr.Rmd")
         f(FALSE) + readRDS(file_in("file.rds"))
       },
       command = FALSE,
       file = TRUE,
       depend = TRUE,
-      change = NULL
+      condition = FALSE
     )
   )
   deps <- c(file_store("file.rds"), file_store("knitr.Rmd"), "f")
   expect_true(all(deps %in% igraph::V(config$graph)$name))
-  expect_equal(sort(dependencies("x", config)), sort(deps))
+  expect_equal(sort(deps_graph("x", config$graph)), sort(deps))
   expect_equal(outdated(config), "x")
-  make(config = config)
+  make(config = config, memory_strategy = "memory")
   expect_equal(justbuilt(config), "x")
   expect_equal(outdated(config), character(0))
-  make(config = config)
+  make(config = config, memory_strategy = "memory")
   nobuild(config)
   f <- function(x) {
     identity(x) || FALSE
@@ -290,14 +301,21 @@ test_with_dir("same, but with global trigger", {
 
 test_with_dir("triggers can be NA in the plan", {
   skip_on_cran()
+  cache <- storr::storr_environment()
   expect_silent(
-    config <- make(
-      drake_plan(x = target(1, NA)),
+    make(
+      drake_plan(x = target(1, trigger = NA)),
       session_info = FALSE,
-      cache = storr::storr_environment(),
+      cache = cache,
       verbose = FALSE
     )
   )
+  config <- drake_config(
+    drake_plan(x = target(1, trigger = NA)),
+    session_info = FALSE,
+    cache = cache,
+    verbose = FALSE
+  )
   expect_equal(justbuilt(config), "x")
 })
 
@@ -317,20 +335,23 @@ test_with_dir("deps load into memory for complex triggers", {
     psi_3 = target(
       command = 1,
       trigger = trigger(change = psi_2)
-    ),
-    strings_in_dots = "literals"
+    )
   )
   for (i in 1:3) {
     make(
       plan, envir = e, jobs = jobs, parallelism = parallelism,
       verbose = FALSE, caching = caching, session_info = FALSE
     )
-    expect_true(all(cached(list = plan$target)))
+    expect_true(all(plan$target %in% cached()))
   }
+  config <- drake_config(plan)
+  expect_equal(config$layout[["psi_2"]]$deps_condition$memory, "psi_1")
+  expect_equal(config$layout[["psi_3"]]$deps_change$memory, "psi_2")
 })
 
 test_with_dir("trigger components react appropriately", {
   skip_on_cran()
+  skip_if_not_installed("knitr")
   scenario <- get_testing_scenario()
   e <- eval(parse(text = scenario$envir))
   jobs <- scenario$jobs
@@ -348,55 +369,66 @@ test_with_dir("trigger components react appropriately", {
   saveRDS(TRUE, "condition.rds")
   plan <- drake_plan(
     missing = target(
-      "",
-      trigger(command = FALSE, depend = FALSE, file = FALSE)
+      NULL,
+      trigger = trigger(command = FALSE, depend = FALSE, file = FALSE)
     ),
     condition = target(
-      "",
-      trigger(
+      NULL,
+      trigger = trigger(
         condition = readRDS("condition.rds"),
         command = FALSE, depend = FALSE, file = FALSE
       )
     ),
     command = target(
-      "",
-      trigger(command = TRUE, depend = FALSE, file = FALSE)
+      NULL,
+      trigger = trigger(command = TRUE, depend = FALSE, file = FALSE)
     ),
     depend = target(
-      "",
-      trigger(command = FALSE, depend = TRUE, file = FALSE)
+      NULL,
+      trigger = trigger(command = FALSE, depend = TRUE, file = FALSE)
     ),
     file = target(
-      "",
-      trigger(command = FALSE, depend = FALSE, file = TRUE)
+      NULL,
+      trigger = trigger(command = FALSE, depend = FALSE, file = TRUE)
     ),
     change = target(
-      "",
-      trigger(
+      NULL,
+      trigger = trigger(
         change = readRDS("change.rds"),
         command = FALSE, depend = FALSE, file = FALSE
       )
-    ),
-    strings_in_dots = "literals"
+    )
   )
-  plan$command <- paste0("
+  commands <- paste0("{
     knitr_in(\"report.Rmd\")
     out <- f(readRDS(file_in(\"file.rds\")))
     saveRDS(out, file_out(\"out_", plan$target, ".rds\"))
     out
-  ")
-  config <- make(
+  }")
+  commands <- lapply(commands, safe_parse)
+  plan$command <- commands
+  make(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
-    verbose = FALSE, caching = caching, session_info = FALSE
+    verbose = 6, caching = caching, session_info = FALSE
+  )
+  config <- drake_config(
+    plan, envir = e, jobs = jobs, parallelism = parallelism,
+    verbose = 6, caching = caching, session_info = FALSE,
+    log_progress = TRUE
   )
   expect_equal(sort(justbuilt(config)), sort(config$plan$target))
   expect_equal(outdated(config), "condition")
   simple_plan <- plan
   simple_plan$trigger <- NULL
-  simple_config <- make(
+  make(
     simple_plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = FALSE, caching = caching, session_info = FALSE
   )
+  simple_config <- drake_config(
+    simple_plan, envir = e, jobs = jobs, parallelism = parallelism,
+    verbose = FALSE, caching = caching, session_info = FALSE,
+    log_progress = TRUE
+  )
 
   # Condition trigger
   for (i in 1:2) {
@@ -472,12 +504,14 @@ test_with_dir("trigger components react appropriately", {
   make(config = simple_config)
 
   # Command trigger
-  config$plan$command <- simple_config$plan$command <- paste0("
+  new_commands <- paste0("{
     knitr_in(\"report.Rmd\")
     out <- f(1 + readRDS(file_in(\"file.rds\")))
     saveRDS(out, file_out(\"out_", plan$target, ".rds\"))
     out
-  ")
+  }")
+  new_commands <- lapply(new_commands, safe_parse)
+  config$plan$command <- simple_config$plan$command <- new_commands
   config$layout <- create_drake_layout(
     plan = config$plan,
     envir = config$envir,
@@ -532,19 +566,33 @@ test_with_dir("trigger whitelist mode", {
     envir = e
   )
   plan <- drake_plan(y = f(1))
-  config <- make(
+  make(
+    plan, envir = e, jobs = jobs, parallelism = parallelism,
+    verbose = 4, caching = caching, session_info = FALSE
+  )
+  config <- drake_config(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 4, caching = caching, session_info = FALSE
   )
   expect_equal(justbuilt(config), "y")
   expect_equal(outdated(config), character(0))
-  config <- make(
+  make(
+    plan, envir = e, jobs = jobs, parallelism = parallelism,
+    verbose = 4, caching = caching, session_info = FALSE,
+    trigger = trigger(condition = FALSE, mode = "whitelist")
+  )
+  config <- drake_config(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 4, caching = caching, session_info = FALSE,
     trigger = trigger(condition = FALSE, mode = "whitelist")
   )
   expect_equal(justbuilt(config), character(0))
-  config <- make(
+  make(
+    plan, envir = e, jobs = jobs, parallelism = parallelism,
+    verbose = 4, caching = caching, session_info = FALSE,
+    trigger = trigger(condition = TRUE, mode = "whitelist")
+  )
+  config <- drake_config(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 4, caching = caching, session_info = FALSE,
     trigger = trigger(condition = TRUE, mode = "whitelist")
@@ -556,7 +604,12 @@ test_with_dir("trigger whitelist mode", {
     }),
     envir = e
   )
-  config <- make(
+  make(
+    plan, envir = e, jobs = jobs, parallelism = parallelism,
+    verbose = 4, caching = caching, session_info = FALSE,
+    trigger = trigger(condition = FALSE, mode = "whitelist")
+  )
+  config <- drake_config(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 4, caching = caching, session_info = FALSE,
     trigger = trigger(condition = FALSE, mode = "whitelist")
@@ -568,7 +621,12 @@ test_with_dir("trigger whitelist mode", {
     }),
     envir = e
   )
-  config <- make(
+  make(
+    plan, envir = e, jobs = jobs, parallelism = parallelism,
+    verbose = 4, caching = caching, session_info = FALSE,
+    trigger = trigger(condition = TRUE, mode = "whitelist")
+  )
+  config <- drake_config(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 4, caching = caching, session_info = FALSE,
     trigger = trigger(condition = TRUE, mode = "whitelist")
@@ -590,19 +648,33 @@ test_with_dir("trigger blacklist mode", {
     envir = e
   )
   plan <- drake_plan(y = f(1))
-  config <- make(
+  make(
+    plan, envir = e, jobs = jobs, parallelism = parallelism,
+    verbose = 4, caching = caching, session_info = FALSE
+  )
+  config <- drake_config(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 4, caching = caching, session_info = FALSE
   )
   expect_equal(justbuilt(config), "y")
   expect_equal(outdated(config), character(0))
-  config <- make(
+  make(
+    plan, envir = e, jobs = jobs, parallelism = parallelism,
+    verbose = 4, caching = caching, session_info = FALSE,
+    trigger = trigger(condition = FALSE, mode = "blacklist")
+  )
+  config <- drake_config(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 4, caching = caching, session_info = FALSE,
     trigger = trigger(condition = FALSE, mode = "blacklist")
   )
   expect_equal(justbuilt(config), character(0))
-  config <- make(
+  make(
+    plan, envir = e, jobs = jobs, parallelism = parallelism,
+    verbose = 4, caching = caching, session_info = FALSE,
+    trigger = trigger(condition = TRUE, mode = "blacklist")
+  )
+  config <- drake_config(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 4, caching = caching, session_info = FALSE,
     trigger = trigger(condition = TRUE, mode = "blacklist")
@@ -614,7 +686,12 @@ test_with_dir("trigger blacklist mode", {
     }),
     envir = e
   )
-  config <- make(
+  make(
+    plan, envir = e, jobs = jobs, parallelism = parallelism,
+    verbose = 4, caching = caching, session_info = FALSE,
+    trigger = trigger(condition = FALSE, mode = "blacklist")
+  )
+  config <- drake_config(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 4, caching = caching, session_info = FALSE,
     trigger = trigger(condition = FALSE, mode = "blacklist")
@@ -626,7 +703,12 @@ test_with_dir("trigger blacklist mode", {
     }),
     envir = e
   )
-  config <- make(
+  make(
+    plan, envir = e, jobs = jobs, parallelism = parallelism,
+    verbose = 4, caching = caching, session_info = FALSE,
+    trigger = trigger(condition = TRUE, mode = "blacklist")
+  )
+  config <- drake_config(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 4, caching = caching, session_info = FALSE,
     trigger = trigger(condition = TRUE, mode = "blacklist")
@@ -648,19 +730,33 @@ test_with_dir("trigger condition mode", {
     envir = e
   )
   plan <- drake_plan(y = f(1))
-  config <- make(
+  make(
+    plan, envir = e, jobs = jobs, parallelism = parallelism,
+    verbose = 4, caching = caching, session_info = FALSE
+  )
+  config <- drake_config(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 4, caching = caching, session_info = FALSE
   )
   expect_equal(justbuilt(config), "y")
   expect_equal(outdated(config), character(0))
-  config <- make(
+  make(
+    plan, envir = e, jobs = jobs, parallelism = parallelism,
+    verbose = 4, caching = caching, session_info = FALSE,
+    trigger = trigger(condition = FALSE, mode = "condition")
+  )
+  config <- drake_config(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 4, caching = caching, session_info = FALSE,
     trigger = trigger(condition = FALSE, mode = "condition")
   )
   expect_equal(justbuilt(config), character(0))
-  config <- make(
+  make(
+    plan, envir = e, jobs = jobs, parallelism = parallelism,
+    verbose = 4, caching = caching, session_info = FALSE,
+    trigger = trigger(condition = TRUE, mode = "condition")
+  )
+  config <- drake_config(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 4, caching = caching, session_info = FALSE,
     trigger = trigger(condition = TRUE, mode = "condition")
@@ -672,7 +768,12 @@ test_with_dir("trigger condition mode", {
     }),
     envir = e
   )
-  config <- make(
+  make(
+    plan, envir = e, jobs = jobs, parallelism = parallelism,
+    verbose = 4, caching = caching, session_info = FALSE,
+    trigger = trigger(condition = FALSE, mode = "condition")
+  )
+  config <- drake_config(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 4, caching = caching, session_info = FALSE,
     trigger = trigger(condition = FALSE, mode = "condition")
@@ -684,10 +785,109 @@ test_with_dir("trigger condition mode", {
     }),
     envir = e
   )
-  config <- make(
+  make(
+    plan, envir = e, jobs = jobs, parallelism = parallelism,
+    verbose = 4, caching = caching, session_info = FALSE,
+    trigger = trigger(condition = TRUE, mode = "condition")
+  )
+  config <- drake_config(
     plan, envir = e, jobs = jobs, parallelism = parallelism,
     verbose = 4, caching = caching, session_info = FALSE,
     trigger = trigger(condition = TRUE, mode = "condition")
   )
   expect_equal(justbuilt(config), "y")
 })
+
+test_with_dir("files are collected/encoded from all triggers", {
+  skip_on_cran()
+  skip_if_not_installed("knitr")
+  exp <- sort(c(
+    paste0(
+      rep(c("command_", "condition_", "change_"), times = 3),
+      rep(c("in", "out", "knitr_in"), each = 3)
+    )
+  ))
+  exp <- setdiff(exp, c("condition_out", "change_out"))
+  file.create(exp)
+  plan <- drake_plan(
+    x = target(
+      command = {
+        file_in("command_in")
+        file_out("command_out")
+        knitr_in("command_knitr_in")
+      },
+      trigger = trigger(
+        condition = {
+          file_in("condition_in")
+          file_out("condition_out")
+          knitr_in("condition_knitr_in")
+        },
+        change = {
+          file_in("change_in")
+          file_out("change_out")
+          knitr_in("change_knitr_in")
+        }
+      )
+    )
+  )
+  config <- drake_config(plan)
+  deps_build <- decode_path(unlist(config$layout[["x"]]$deps_build))
+  deps_condition <- decode_path(
+    unlist(config$layout[["x"]]$deps_condition))
+  deps_change <- decode_path(unlist(config$layout[["x"]]$deps_change))
+  expect_equal(
+    sort(deps_build),
+    sort(c("command_in", "command_out", "command_knitr_in"))
+  )
+  expect_equal(
+    sort(deps_condition),
+    sort(c("condition_in", "condition_knitr_in"))
+  )
+  expect_equal(
+    sort(deps_change),
+    sort(c("change_in", "change_knitr_in"))
+  )
+})
+
+test_with_dir("GitHub issue #704", {
+  add <- function(a, b) {
+    a + b
+  }
+  square <- function(x) {
+    x ^ 2
+  }
+  rand_is_even <- function(samp_size) {
+    num <- sample(samp_size, 1)
+    if (num %% 2 == 0) {
+      TRUE
+    } else {
+      FALSE
+    }
+  }
+  check_plan <- function(plan) {
+    cache <- storr::storr_environment()
+    make(plan, cache = cache, session_info = FALSE)
+    expect_true(is.numeric(cache$get("first")))
+    expect_true(is.numeric(cache$get("second")))
+  }
+  plan <- drake_plan(
+    first = add(2, 3),
+    second = target(
+      command = square(first),
+      trigger = trigger(
+        condition = rand_is_even(first)
+      )
+    )
+  )
+  check_plan(plan)
+  plan <- drake_plan(
+    first = add(2, 3),
+    second = target(
+      command = square(first),
+      trigger = trigger(
+        change = rand_is_even(first)
+      )
+    )
+  )
+  check_plan(plan)
+})
